diff --git a/Tools/ArdupilotMegaPlanner/Utilities/ParameterMetaDataParser.cs b/Tools/ArdupilotMegaPlanner/Utilities/ParameterMetaDataParser.cs
index 50a725698a..5554bbce73 100644
--- a/Tools/ArdupilotMegaPlanner/Utilities/ParameterMetaDataParser.cs
+++ b/Tools/ArdupilotMegaPlanner/Utilities/ParameterMetaDataParser.cs
@@ -41,7 +41,7 @@ namespace ArdupilotMega.Utilities
// Read and parse the content.
string dataFromAddress = ReadDataFromAddress(parameterLocation);
- ParseLibInformation(dataFromAddress, objXmlTextWriter, parameterLocation);
+ ParseGroupInformation(dataFromAddress, objXmlTextWriter, parameterLocation);
ParseParameterInformation(dataFromAddress, objXmlTextWriter);
// Write the end element for this parameter location
@@ -58,12 +58,12 @@ namespace ArdupilotMega.Utilities
}
///
/// Parses the lib information.
///
/// The file contents.
/// The obj XML text writer.
/// The parameter location.
- private static void ParseLibInformation(string fileContents, XmlTextWriter objXmlTextWriter, string parameterLocation)
+ private static void ParseGroupInformation(string fileContents, XmlTextWriter objXmlTextWriter, string parameterLocation)
{
var parsedInformation = ParseKeyValuePairs(fileContents, ParameterMetaDataConstants.Group);
if (parsedInformation != null && parsedInformation.Count > 0)
@@ -58,12 +58,12 @@ namespace ArdupilotMega.Utilities
}
///
- /// Parses the lib information.
+ /// Parses the group parameter information.
///
/// The file contents.